@@ -77,10 +77,10 @@ class Storage(MinioUtility):
     def __init__(self, minio_config):
         self.instance = Minio(secure=False, **minio_config)
 
-    def upload_file(bucket, uri, file):
+    def upload_file(self, bucket, uri, file):
         self.add_object(bucket, uri, file)
     
-    def upload_file_by_bytes(bucket, uri, bytes):
+    def upload_file_by_bytes(self, bucket, uri, bytes):
         self.add_object(bucket, uri, BytesIO(bytes))
 
     def download_file(self, path):
@@ -95,7 +95,7 @@ class Storage(MinioUtility):
         file_bytes = file.read()
         return file_bytes
 
-    def remove_file(path):
+    def remove_file(self, path):
         if not path:
             return 
         path_layers = path.split('/')
